@@ -9,7 +9,11 @@
 ** Please send bug fixes/bug reports to: Peter Eriksson <pen@lysator.liu.se>
 */
 
-#if defined(IRIX) || defined(SVR4) || defined(NeXT) || (defined(sco) && sco >= 42) || defined(_AIX4) || defined(__FreeBSD__)
+#if !defined(__STDC__)
+#define void int
+#endif
+
+#if defined(IRIX) || defined(SVR4) || defined(NeXT) || (defined(sco) && sco >= 42) || defined(_AIX4) || defined(__FreeBSD__) || defined(ultrix)
 #  define SIGRETURN_TYPE void
 #  define SIGRETURN_TYPE_IS_VOID
 #else
@@ -156,11 +160,13 @@ char *inet_ntoa(ad)
 }
 #endif
 
-static int comparemem(p1, p2, len)
-    unsigned char *p1;
-    unsigned char *p2;
-    int len;
+static int comparemem(vp1, vp2, len)
+     void *vp1;
+     void *vp2;
+     int len;
 {
+    unsigned char *p1 = (unsigned char *) vp1;
+    unsigned char *p2 = (unsigned char *) vp2;
     int c;
 
     while (len-- > 0)
@@ -241,10 +247,11 @@ child_handler()
 #endif
 
 
-char *clearmem(bp, len)
-    char *bp;
-    int len;
+char *clearmem(vbp, len)
+     void *vbp;
+     int len;
 {
+    char *bp = (char *) vbp;
     char *cp;
 
     cp = bp;
@@ -542,7 +549,7 @@ int main(argc,argv)
 	if (fd != 0)
 	    dup2(fd, 0);
 	
-	clearmem((unsigned char *) &addr, sizeof(addr));
+	clearmem(&addr, sizeof(addr));
 	
 	addr.sin_family = AF_INET;
 	if (bind_address == NULL)
@@ -580,9 +587,12 @@ int main(argc,argv)
 
 	if (bind(0, (struct sockaddr *) &addr, sizeof(addr)) < 0)
 	    ERROR("main: bind");
-	
-	if (listen(0, 3) < 0)
-	    ERROR("main: listen");
+    }
+    
+    if (background_flag)
+    {
+      if (listen(0, 3) < 0)
+	ERROR("main: listen");
     }
     
     if (set_gid)
@@ -755,7 +765,7 @@ int main(argc,argv)
 	openlog("identd", LOG_PID);
 #endif
 
-#ifndef STRONG_LOG
+#ifdef STRONG_LOG
 	syslog(LOG_INFO, "Connection from %s", gethost(&faddr));
 #endif
     }
