@@ -31,7 +31,7 @@
 #ifdef HAVE_KVM
 #  include <kvm.h>
 #else
-#  include "kernel/kvm.h"
+#  include "kvm.h"
 #endif
 
 #include <sys/types.h>
